pub struct ClusterNode {
pub id: String,
pub address: String,
pub grpc_port: u32,
pub status: i32,
pub shards: Vec<u32>,
pub metadata: Option<NodeMetadata>,
}Fields
id: Stringaddress: Stringgrpc_port: u32status: i32shards: Vec<u32>shard IDs
metadata: Option<NodeMetadata>Implementations
Sourceimpl ClusterNode
impl ClusterNode
Sourcepub fn status(&self) -> NodeStatus
pub fn status(&self) -> NodeStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: NodeStatus)
pub fn set_status(&mut self, value: NodeStatus)
Sets status to the provided enum value.