Module qdrant_proto

Module qdrant_proto 

Qdrant compatibility schema (proto/qdrant/*.proto).

Modules

alias_operations
Nested message and enum types in AliasOperations.
binary_quantization_query_encoding
Nested message and enum types in BinaryQuantizationQueryEncoding.
collections_client
Generated client implementations.
collections_server
Generated server implementations.
condition
Nested message and enum types in Condition.
expression
Nested message and enum types in Expression.
facet_value
Nested message and enum types in FacetValue.
group_id
Nested message and enum types in GroupId.
match
Nested message and enum types in Match.
max_optimization_threads
Nested message and enum types in MaxOptimizationThreads.
order_value
Nested message and enum types in OrderValue.
payload_index_params
Nested message and enum types in PayloadIndexParams.
point_id
Nested message and enum types in PointId.
points_client
Generated client implementations.
points_selector
Nested message and enum types in PointsSelector.
points_server
Generated server implementations.
points_update_operation
Nested message and enum types in PointsUpdateOperation.
quantization_config
Nested message and enum types in QuantizationConfig.
quantization_config_diff
Nested message and enum types in QuantizationConfigDiff.
query
Nested message and enum types in Query.
read_consistency
Nested message and enum types in ReadConsistency.
shard_key
Nested message and enum types in ShardKey.
snapshots_client
Generated client implementations.
snapshots_server
Generated server implementations.
start_from
Nested message and enum types in StartFrom.
stemming_algorithm
Nested message and enum types in StemmingAlgorithm.
target_vector
Nested message and enum types in TargetVector.
update_collection_cluster_setup_request
Nested message and enum types in UpdateCollectionClusterSetupRequest.
value
Nested message and enum types in Value.
vector
Nested message and enum types in Vector.
vector_example
Nested message and enum types in VectorExample.
vector_input
Nested message and enum types in VectorInput.
vector_output
Nested message and enum types in VectorOutput.
vectors
Nested message and enum types in Vectors.
vectors_config
Nested message and enum types in VectorsConfig.
vectors_config_diff
Nested message and enum types in VectorsConfigDiff.
vectors_output
Nested message and enum types in VectorsOutput.
with_payload_selector
Nested message and enum types in WithPayloadSelector.
with_vectors_selector
Nested message and enum types in WithVectorsSelector.

Structs

AbortShardTransfer
AcornSearchParams
AliasDescription
AliasOperations
BatchResult
BinaryQuantization
BinaryQuantizationQueryEncoding
BoolIndexParams
ChangeAliases
ClearPayloadPoints
CollectionClusterInfoRequest
CollectionClusterInfoResponse
CollectionConfig
CollectionDescription
CollectionExists
CollectionExistsRequest
CollectionExistsResponse
CollectionInfo
CollectionOperationResponse
CollectionParams
CollectionParamsDiff
CollectionWarning
Condition
ContextExamplePair
ContextInput
ContextInputPair
CountPoints
CountResponse
CountResult
CreateAlias
CreateCollection
CreateFieldIndexCollection
CreateFullSnapshotRequest
CreateShardKey
CreateShardKeyRequest
CreateShardKeyResponse
CreateSnapshotRequest
CreateSnapshotResponse
DatetimeIndexParams
DatetimeRange
DecayParamsExpression
DeleteAlias
DeleteCollection
DeleteFieldIndexCollection
DeleteFullSnapshotRequest
DeletePayloadPoints
DeletePointVectors
DeletePoints
DeleteShardKey
DeleteShardKeyRequest
DeleteShardKeyResponse
DeleteSnapshotRequest
DeleteSnapshotResponse
DenseVector
Disabled
DiscoverBatchPoints
DiscoverBatchResponse
DiscoverInput
DiscoverPoints
DiscoverResponse
DivExpression
Document
Expression
FacetCounts
FacetHit
FacetResponse
FacetValue
FieldCondition
Filter
FloatIndexParams
Formula
GeoBoundingBox
GeoDistance
GeoIndexParams
GeoLineString
GeoPoint
GeoPolygon
For a valid GeoPolygon, both the exterior and interior GeoLineStrings must consist of a minimum of 4 points. Additionally, the first and last points of each GeoLineString must be the same.
GeoRadius
GetCollectionInfoRequest
GetCollectionInfoResponse
GetPoints
GetResponse
GroupId
GroupsResult
HardwareUsage
HasIdCondition
HasVectorCondition
HnswConfigDiff
Image
InferenceObject
InferenceUsage
IntegerIndexParams
IsEmptyCondition
IsNullCondition
KeywordIndexParams
ListAliasesRequest
ListAliasesResponse
ListCollectionAliasesRequest
ListCollectionsRequest
ListCollectionsResponse
ListFullSnapshotsRequest
ListSnapshotsRequest
ListSnapshotsResponse
ListValue
ListValue is a wrapper around a repeated field of values.
LocalShardInfo
LookupLocation
Match
MaxOptimizationThreads
MinShould
Mmr
Maximal Marginal Relevance (MMR) algorithm for re-ranking the points.
ModelUsage
MoveShard
MultExpression
MultiDenseVector
MultiVectorConfig
NamedVectors
NamedVectorsOutput
NearestInputWithMmr
NestedCondition
OptimizerStatus
OptimizersConfigDiff
OrderBy
OrderValue
PayloadExcludeSelector
PayloadIncludeSelector
PayloadIndexParams
PayloadSchemaInfo
PointGroup
PointId
PointStruct
PointVectors
PointsIdsList
PointsOperationResponse
PointsSelector
PointsUpdateOperation
PowExpression
PrefetchQuery
ProductQuantization
QuantizationConfig
QuantizationConfigDiff
QuantizationSearchParams
Query
QueryBatchPoints
QueryBatchResponse
QueryGroupsResponse
QueryPointGroups
QueryPoints
QueryResponse
Range
ReadConsistency
RecommendBatchPoints
RecommendBatchResponse
RecommendGroupsResponse
RecommendInput
RecommendPointGroups
RecommendPoints
RecommendResponse
RemoteShardInfo
RenameAlias
RepeatedIntegers
RepeatedStrings
Replica
ReplicatePoints
ReplicateShard
ReshardingInfo
RestartTransfer
RetrievedPoint
Rrf
Parameterized reciprocal rank fusion
ScalarQuantization
ScoredPoint
ScrollPoints
ScrollResponse
SearchBatchPoints
SearchBatchResponse
SearchGroupsResponse
SearchMatrixOffsets
SearchMatrixOffsetsResponse
SearchMatrixPair
SearchMatrixPairs
SearchMatrixPairsResponse
SearchMatrixPoints
SearchParams
SearchPointGroups
SearchPoints
SearchResponse
SetPayloadPoints
ShardKey
ShardKeySelector
ShardTransferInfo
SnapshotDescription
SnowballParams
SparseIndexConfig
SparseIndices
SparseVector
SparseVectorConfig
SparseVectorParams
StartFrom
StemmingAlgorithm
StopwordsSet
StrictModeConfig
StrictModeMultivector
StrictModeMultivectorConfig
StrictModeSparse
StrictModeSparseConfig
Struct
Struct represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, Struct might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.
SumExpression
TargetVector
TextIndexParams
UpdateBatchPoints
UpdateBatchResponse
UpdateCollection
UpdateCollectionClusterSetupRequest
UpdateCollectionClusterSetupResponse
UpdatePointVectors
UpdateResult
UpsertPoints
Usage

UuidIndexParams
Value
Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of those variants, absence of any variant indicates an error.
ValuesCount
Vector
VectorExample
VectorInput
Vector type to be used in queries. Ids will be substituted with their corresponding vectors from the collection.
VectorOutput
VectorParams
VectorParamsDiff
VectorParamsDiffMap
VectorParamsMap
Vectors
VectorsConfig
VectorsConfigDiff
VectorsOutput
VectorsSelector
WalConfigDiff
WithLookup
WithPayloadSelector
WithVectorsSelector
WriteOrdering

Enums

BinaryQuantizationEncoding
CollectionStatus
CompressionRatio
Datatype
Direction
Distance
FieldType
Fusion
Modifier
MultiVectorComparator
NullValue
NullValue is a singleton enumeration to represent the null value for the Value type union.
PayloadSchemaType
QuantizationType
ReadConsistencyType
RecommendStrategy
How to use positive and negative vectors to find the results, default is AverageVector.
ReplicaState
ReshardingDirection
Resharding direction, scale up or down in number of shards
Sample
Sample points from the collection
ShardTransferMethod
ShardingMethod
TokenizerType
UpdateStatus
WriteOrderingType