pub struct CollectionConfig {
pub dimension: u32,
pub metric: i32,
pub hnsw_config: Option<HnswConfig>,
pub quantization: Option<QuantizationConfig>,
pub storage_type: i32,
}Expand description
Common data structures
Fields
dimension: u32metric: i32hnsw_config: Option<HnswConfig>quantization: Option<QuantizationConfig>storage_type: i32Implementations
Sourceimpl CollectionConfig
impl CollectionConfig
Sourcepub fn metric(&self) -> DistanceMetric
pub fn metric(&self) -> DistanceMetric
Returns the enum value of metric, or the default if the field is set to an invalid enum value.
Sourcepub fn set_metric(&mut self, value: DistanceMetric)
pub fn set_metric(&mut self, value: DistanceMetric)
Sets metric to the provided enum value.
Sourcepub fn storage_type(&self) -> StorageType
pub fn storage_type(&self) -> StorageType
Returns the enum value of storage_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_storage_type(&mut self, value: StorageType)
pub fn set_storage_type(&mut self, value: StorageType)
Sets storage_type to the provided enum value.