pub struct HybridSearchConfig {
pub dense_k: u32,
pub sparse_k: u32,
pub final_k: u32,
pub alpha: f64,
pub algorithm: i32,
}Fields
dense_k: u32sparse_k: u32final_k: u32alpha: f64algorithm: i32Implementations
Sourceimpl HybridSearchConfig
impl HybridSearchConfig
Sourcepub fn algorithm(&self) -> HybridScoringAlgorithm
pub fn algorithm(&self) -> HybridScoringAlgorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: HybridScoringAlgorithm)
pub fn set_algorithm(&mut self, value: HybridScoringAlgorithm)
Sets algorithm to the provided enum value.